==> devops-client-java-1.0.6-sources.jar: io/alauda/devops/java/client/models/V1alpha1ListIssuesOptionsFluentImpl.java <==
package io.alauda.devops.java.client.models;

import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.alauda.devops.java.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1alpha1ListIssuesOptionsFluentImpl<A extends V1alpha1ListIssuesOptionsFluent<A>> extends io.alauda.devops.java.client.fluent.BaseFluent<A> implements V1alpha1ListIssuesOptionsFluent<A>{

    private String apiVersion;
    private String issuekey;
    private String kind;
    private String orderby;
    private Integer page;
    private Integer pagesize;
    private String priority;
    private String project;
    private String sort;
    private String status;
    private String summary;
    private String type;

    public V1alpha1ListIssuesOptionsFluentImpl(){
    }
    public V1alpha1ListIssuesOptionsFluentImpl(V1alpha1ListIssuesOptions instance){
            this.withApiVersion(instance.getApiVersion());

            this.withIssuekey(instance.getIssuekey());

            this.withKind(instance.getKind());

            this.withOrderby(instance.getOrderby());

            this.withPage(instance.getPage());

            this.withPagesize(instance.getPagesize());

            this.withPriority(instance.getPriority());

            this.withProject(instance.getProject());

            this.withSort(instance.getSort());

            this.withStatus(instance.getStatus());

            this.withSummary(instance.getSummary());

            this.withType(instance.getType());

    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public String getIssuekey(){
            return this.issuekey;
    }

    public A withIssuekey(String issuekey){
            this.issuekey=issuekey; return (A) this;
    }

    public Boolean hasIssuekey(){
            return this.issuekey != null;
    }

    public A withNewIssuekey(String arg1){
            return (A)withIssuekey(new String(arg1));
    }

    public A withNewIssuekey(StringBuilder arg1){
            return (A)withIssuekey(new String(arg1));
    }

    public A withNewIssuekey(StringBuffer arg1){
            return (A)withIssuekey(new String(arg1));
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public A withNewKind(String arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1){
            return (A)withKind(new String(arg1));
    }

    public String getOrderby(){
            return this.orderby;
    }

    public A withOrderby(String orderby){
            this.orderby=orderby; return (A) this;
    }

    public Boolean hasOrderby(){
            return this.orderby != null;
    }

    public A withNewOrderby(String arg1){
            return (A)withOrderby(new String(arg1));
    }

    public A withNewOrderby(StringBuilder arg1){
            return (A)withOrderby(new String(arg1));
    }

    public A withNewOrderby(StringBuffer arg1){
            return (A)withOrderby(new String(arg1));
    }

    public Integer getPage(){
            return this.page;
    }

    public A withPage(Integer page){
            this.page=page; return (A) this;
    }

    public Boolean hasPage(){
            return this.page != null;
    }

    public Integer getPagesize(){
            return this.pagesize;
    }

    public A withPagesize(Integer pagesize){
            this.pagesize=pagesize; return (A) this;
    }

    public Boolean hasPagesize(){
            return this.pagesize != null;
    }

    public String getPriority(){
            return this.priority;
    }

    public A withPriority(String priority){
            this.priority=priority; return (A) this;
    }

    public Boolean hasPriority(){
            return this.priority != null;
    }

    public A withNewPriority(String arg1){
            return (A)withPriority(new String(arg1));
    }

    public A withNewPriority(StringBuilder arg1){
            return (A)withPriority(new String(arg1));
    }

    public A withNewPriority(StringBuffer arg1){
            return (A)withPriority(new String(arg1));
    }

    public String getProject(){
            return this.project;
    }

    public A withProject(String project){
            this.project=project; return (A) this;
    }

    public Boolean hasProject(){
            return this.project != null;
    }

    public A withNewProject(String arg1){
            return (A)withProject(new String(arg1));
    }

    public A withNewProject(StringBuilder arg1){
            return (A)withProject(new String(arg1));
    }

    public A withNewProject(StringBuffer arg1){
            return (A)withProject(new String(arg1));
    }

    public String getSort(){
            return this.sort;
    }

    public A withSort(String sort){
            this.sort=sort; return (A) this;
    }

    public Boolean hasSort(){
            return this.sort != null;
    }

    public A withNewSort(String arg1){
            return (A)withSort(new String(arg1));
    }

    public A withNewSort(StringBuilder arg1){
            return (A)withSort(new String(arg1));
    }

    public A withNewSort(StringBuffer arg1){
            return (A)withSort(new String(arg1));
    }

    public String getStatus(){
            return this.status;
    }

    public A withStatus(String status){
            this.status=status; return (A) this;
    }

    public Boolean hasStatus(){
            return this.status != null;
    }

    public A withNewStatus(String arg1){
            return (A)withStatus(new String(arg1));
    }

    public A withNewStatus(StringBuilder arg1){
            return (A)withStatus(new String(arg1));
    }

    public A withNewStatus(StringBuffer arg1){
            return (A)withStatus(new String(arg1));
    }

    public String getSummary(){
            return this.summary;
    }

    public A withSummary(String summary){
            this.summary=summary; return (A) this;
    }

    public Boolean hasSummary(){
            return this.summary != null;
    }

    public A withNewSummary(String arg1){
            return (A)withSummary(new String(arg1));
    }

    public A withNewSummary(StringBuilder arg1){
            return (A)withSummary(new String(arg1));
    }

    public A withNewSummary(StringBuffer arg1){
            return (A)withSummary(new String(arg1));
    }

    public String getType(){
            return this.type;
    }

    public A withType(String type){
            this.type=type; return (A) this;
    }

    public Boolean hasType(){
            return this.type != null;
    }

    public A withNewType(String arg1){
            return (A)withType(new String(arg1));
    }

    public A withNewType(StringBuilder arg1){
            return (A)withType(new String(arg1));
    }

    public A withNewType(StringBuffer arg1){
            return (A)withType(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1alpha1ListIssuesOptionsFluentImpl that = (V1alpha1ListIssuesOptionsFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (issuekey != null ? !issuekey.equals(that.issuekey) :that.issuekey != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (orderby != null ? !orderby.equals(that.orderby) :that.orderby != null) return false;
            if (page != null ? !page.equals(that.page) :that.page != null) return false;
            if (pagesize != null ? !pagesize.equals(that.pagesize) :that.pagesize != null) return false;
            if (priority != null ? !priority.equals(that.priority) :that.priority != null) return false;
            if (project != null ? !project.equals(that.project) :that.project != null) return false;
            if (sort != null ? !sort.equals(that.sort) :that.sort != null) return false;
            if (status != null ? !status.equals(that.status) :that.status != null) return false;
            if (summary != null ? !summary.equals(that.summary) :that.summary != null) return false;
            if (type != null ? !type.equals(that.type) :that.type != null) return false;
            return true;
    }




}

==> devops-client-java-1.0.6.1-sources.jar: io/alauda/devops/java/client/models/V1alpha1ListIssuesOptionsFluentImpl.java <==
package io.alauda.devops.java.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import java.util.ArrayList;
import java.lang.String;
import io.alauda.devops.java.client.fluent.Predicate;
import java.lang.Integer;
import java.lang.StringBuffer;
import io.alauda.devops.java.client.fluent.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class V1alpha1ListIssuesOptionsFluentImpl<A extends V1alpha1ListIssuesOptionsFluent<A>> extends io.alauda.devops.java.client.fluent.BaseFluent<A> implements V1alpha1ListIssuesOptionsFluent<A>{

    private String apiVersion;
    private String issuekey;
    private String kind;
    private String orderby;
    private Integer page;
    private Integer pagesize;
    private String priority;
    private String project;
    private List<String> projects;
    private String sort;
    private String status;
    private String summary;
    private String type;

    public V1alpha1ListIssuesOptionsFluentImpl(){
    }
    public V1alpha1ListIssuesOptionsFluentImpl(V1alpha1ListIssuesOptions instance){
            this.withApiVersion(instance.getApiVersion());

            this.withIssuekey(instance.getIssuekey());

            this.withKind(instance.getKind());

            this.withOrderby(instance.getOrderby());

            this.withPage(instance.getPage());

            this.withPagesize(instance.getPagesize());

            this.withPriority(instance.getPriority());

            this.withProject(instance.getProject());

            this.withProjects(instance.getProjects());

            this.withSort(instance.getSort());

            this.withStatus(instance.getStatus());

            this.withSummary(instance.getSummary());

            this.withType(instance.getType());

    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public String getIssuekey(){
            return this.issuekey;
    }

    public A withIssuekey(String issuekey){
            this.issuekey=issuekey; return (A) this;
    }

    public Boolean hasIssuekey(){
            return this.issuekey != null;
    }

    public A withNewIssuekey(String arg1){
            return (A)withIssuekey(new String(arg1));
    }

    public A withNewIssuekey(StringBuilder arg1){
            return (A)withIssuekey(new String(arg1));
    }

    public A withNewIssuekey(StringBuffer arg1){
            return (A)withIssuekey(new String(arg1));
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public A withNewKind(String arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1){
            return (A)withKind(new String(arg1));
    }

    public String getOrderby(){
            return this.orderby;
    }

    public A withOrderby(String orderby){
            this.orderby=orderby; return (A) this;
    }

    public Boolean hasOrderby(){
            return this.orderby != null;
    }

    public A withNewOrderby(String arg1){
            return (A)withOrderby(new String(arg1));
    }

    public A withNewOrderby(StringBuilder arg1){
            return (A)withOrderby(new String(arg1));
    }

    public A withNewOrderby(StringBuffer arg1){
            return (A)withOrderby(new String(arg1));
    }

    public Integer getPage(){
            return this.page;
    }

    public A withPage(Integer page){
            this.page=page; return (A) this;
    }

    public Boolean hasPage(){
            return this.page != null;
    }

    public Integer getPagesize(){
            return this.pagesize;
    }

    public A withPagesize(Integer pagesize){
            this.pagesize=pagesize; return (A) this;
    }

    public Boolean hasPagesize(){
            return this.pagesize != null;
    }

    public String getPriority(){
            return this.priority;
    }

    public A withPriority(String priority){
            this.priority=priority; return (A) this;
    }

    public Boolean hasPriority(){
            return this.priority != null;
    }

    public A withNewPriority(String arg1){
            return (A)withPriority(new String(arg1));
    }

    public A withNewPriority(StringBuilder arg1){
            return (A)withPriority(new String(arg1));
    }

    public A withNewPriority(StringBuffer arg1){
            return (A)withPriority(new String(arg1));
    }

    public String getProject(){
            return this.project;
    }

    public A withProject(String project){
            this.project=project; return (A) this;
    }

    public Boolean hasProject(){
            return this.project != null;
    }

    public A withNewProject(String arg1){
            return (A)withProject(new String(arg1));
    }

    public A withNewProject(StringBuilder arg1){
            return (A)withProject(new String(arg1));
    }

    public A withNewProject(StringBuffer arg1){
            return (A)withProject(new String(arg1));
    }

    public A addToProjects(int index,String item){
            if (this.projects == null) {this.projects = new ArrayList<String>();}
            this.projects.add(index, item);
            return (A)this;
    }

    public A setToProjects(int index,String item){
            if (this.projects == null) {this.projects = new ArrayList<String>();}
            this.projects.set(index, item); return (A)this;
    }

    public A addToProjects(String... items){
            if (this.projects == null) {this.projects = new ArrayList<String>();}
            for (String item : items) {this.projects.add(item);} return (A)this;
    }

    public A addAllToProjects(Collection<String> items){
            if (this.projects == null) {this.projects = new ArrayList<String>();}
            for (String item : items) {this.projects.add(item);} return (A)this;
    }

    public A removeFromProjects(String... items){
            for (String item : items) {if (this.projects!= null){ this.projects.remove(item);}} return (A)this;
    }

    public A removeAllFromProjects(Collection<String> items){
            for (String item : items) {if (this.projects!= null){ this.projects.remove(item);}} return (A)this;
    }

    public List<String> getProjects(){
            return this.projects;
    }

    public String getProject(int index){
            return this.projects.get(index);
    }

    public String getFirstProject(){
            return this.projects.get(0);
    }

    public String getLastProject(){
            return this.projects.get(projects.size() - 1);
    }

    public String getMatchingProject(io.alauda.devops.java.client.fluent.Predicate<String> predicate){
            for (String item: projects) { if(predicate.apply(item)){return item;} } return null;
    }

    public Boolean hasMatchingProject(io.alauda.devops.java.client.fluent.Predicate<String> predicate){
            for (String item: projects) { if(predicate.apply(item)){return true;} } return false;
    }

    public A withProjects(List<String> projects){
            if (this.projects != null) { _visitables.get("projects").removeAll(this.projects);}
            if (projects != null) {this.projects = new ArrayList<String>(); for (String item : projects){this.addToProjects(item);}} else { this.projects = null;} return (A) this;
    }

    public A withProjects(String... projects){
            if (this.projects != null) {this.projects.clear();}
            if (projects != null) {for (String item :projects){ this.addToProjects(item);}} return (A) this;
    }

    public Boolean hasProjects(){
            return projects != null && !projects.isEmpty();
    }

    public A addNewProject(String arg1){
            return (A)addToProjects(new String(arg1));
    }

    public A addNewProject(StringBuilder arg1){
            return (A)addToProjects(new String(arg1));
    }

    public A addNewProject(StringBuffer arg1){
            return (A)addToProjects(new String(arg1));
    }

    public String getSort(){
            return this.sort;
    }

    public A withSort(String sort){
            this.sort=sort; return (A) this;
    }

    public Boolean hasSort(){
            return this.sort != null;
    }

    public A withNewSort(String arg1){
            return (A)withSort(new String(arg1));
    }

    public A withNewSort(StringBuilder arg1){
            return (A)withSort(new String(arg1));
    }

    public A withNewSort(StringBuffer arg1){
            return (A)withSort(new String(arg1));
    }

    public String getStatus(){
            return this.status;
    }

    public A withStatus(String status){
            this.status=status; return (A) this;
    }

    public Boolean hasStatus(){
            return this.status != null;
    }

    public A withNewStatus(String arg1){
            return (A)withStatus(new String(arg1));
    }

    public A withNewStatus(StringBuilder arg1){
            return (A)withStatus(new String(arg1));
    }

    public A withNewStatus(StringBuffer arg1){
            return (A)withStatus(new String(arg1));
    }

    public String getSummary(){
            return this.summary;
    }

    public A withSummary(String summary){
            this.summary=summary; return (A) this;
    }

    public Boolean hasSummary(){
            return this.summary != null;
    }

    public A withNewSummary(String arg1){
            return (A)withSummary(new String(arg1));
    }

    public A withNewSummary(StringBuilder arg1){
            return (A)withSummary(new String(arg1));
    }

    public A withNewSummary(StringBuffer arg1){
            return (A)withSummary(new String(arg1));
    }

    public String getType(){
            return this.type;
    }

    public A withType(String type){
            this.type=type; return (A) this;
    }

    public Boolean hasType(){
            return this.type != null;
    }

    public A withNewType(String arg1){
            return (A)withType(new String(arg1));
    }

    public A withNewType(StringBuilder arg1){
            return (A)withType(new String(arg1));
    }

    public A withNewType(StringBuffer arg1){
            return (A)withType(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1alpha1ListIssuesOptionsFluentImpl that = (V1alpha1ListIssuesOptionsFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (issuekey != null ? !issuekey.equals(that.issuekey) :that.issuekey != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (orderby != null ? !orderby.equals(that.orderby) :that.orderby != null) return false;
            if (page != null ? !page.equals(that.page) :that.page != null) return false;
            if (pagesize != null ? !pagesize.equals(that.pagesize) :that.pagesize != null) return false;
            if (priority != null ? !priority.equals(that.priority) :that.priority != null) return false;
            if (project != null ? !project.equals(that.project) :that.project != null) return false;
            if (projects != null ? !projects.equals(that.projects) :that.projects != null) return false;
            if (sort != null ? !sort.equals(that.sort) :that.sort != null) return false;
            if (status != null ? !status.equals(that.status) :that.status != null) return false;
            if (summary != null ? !summary.equals(that.summary) :that.summary != null) return false;
            if (type != null ? !type.equals(that.type) :that.type != null) return false;
            return true;
    }




}
